# Documention for `anatrans` python package

## How to use anatrans

A collection of analytical and semi-semianalytical solutions for hydrogeological transport phenomena

## Installation

To install anatrans from GitHub repository, do:

```console
git clone git@github.com:MiBiPreT/anatrans.git
cd anatrans
python -m pip install .
```
